==> dl.php?src=linea21_1_4.zip: linea21/languages/fr/lang_news.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "actualités";

/*	nommage des modules
 *  	*/
$lang['news']['name']='actualité';
$lang['news']['confirm_add'] = "Ajout de la nouvelle actualité réalisé avec succès\n";
$lang['news']['confirm_mod'] = "Modification de l'actualité réalisée avec succès\n";
$lang['news']['confirm_sup'] ="Suppression de l'actualité réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Ajout d\'une '.$lang['news']['name'];
$lang['news']['mod']= 'Modification d\'une '.$lang['news']['name'];
$lang['news']['sup']= 'Suppression de l\''.$lang['news']['name'];
$lang['news']['det']= 'Détails de l\''.$lang['news']['name'];
$lang['news']['list']= 'Consultation des actualités';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Saisie des informations de la nouvelle '.$lang['news']['name'];
$lang['news']['mod_title']='Modification des informations de l\''.$lang['news']['name'];
$lang['news']['recap_commment']='aucun commentaire';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='Votre actualité doit impérativement être associée à une échelle';
$lang['news']['no_level']='Votre actualité doit impérativement être associée à un niveau';
$lang['news']['no_theme']='Votre actualité doit impérativement être associée à un thème';
$lang['news']['no_title']='Votre actualité doit impérativement contenir un titre';
$lang['news']['no_body']='Votre actualité doit impérativement avoir un contenu';
$lang['news']['no_header']='Votre actualité doit impérativement contenir un résumé';
$lang['news']['no_template']='Vous devez impérativement choisir un modèle de présentation pour votre actualité';
$lang['news']['no_visu1']='Vous avez choisi un modèle de présentation avec 1 visuel. Prenez garde à nous le fournir';
$lang['news']['no_visu2']='Vous avez choisi un modèle de présentation avec 2 visuels. Prenez garde à nous les fournir';




/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='Titre de l\''.$lang['news']['name'];
$lang['news']['header']= 'entête';
$lang['news']['body']= 'contenu';
$lang['news']['theme']='thème de rattachement';
$lang['news']['level']='niveau de rattachement';
$lang['news']['scale']='échelle de rattachement';
$lang['news']['template']='modèle de présentation';
$lang['news']['statut']='état de publication';
$lang['news']['photouri']='Visuel(s) associé(s)';
$lang['news']['visu1']='visuel n°1';
$lang['news']['visu2']='visuel n°2';
$lang['news']['author']='auteur';

$lang['news']['template_1']='Texte + photo à gauche';
$lang['news']['template_2']='Texte + photo à droite';
$lang['news']['template_3']='Texte + 2 photos (quinconce)';
$lang['news']['template_4']='Texte seulement';




/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' derniers ajouts effectués';
$lang['news']['qb_titlemod']=' dernières modifications effectuées';
$lang['news']['qb_titlesup']=' dernières suppressions effectuées';
$lang['news']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['news']['nb_total']='actualités sont stockées dans la base de données.';
$lang['news']['statut_filter']='Afficher par statut';
$lang['news']['all']='Afficher la liste complete';
$lang['news']['noresult']='Aucune actualité ne correspond à ce critère de sélection ';


/*	public
 *  	*/

$lang['news']['name2']='actualité(s)';
$lang['news']['next_news']='Voir l\'actualité suivante ';
$lang['news']['prev_news']='Voir l\'actualité précédente ';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='Pour ajouter une actualité, saisissez les informations requises dans le formulaire ci-dessus.';
$lang['news']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['news']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['news']['help_list1']='Pour afficher le détail d\'une actualité, cliquez sur le titre de celle-ci';
$lang['news']['help_list2']='Vous pouvez supprimer une actualité en cliquant sur l\'icône de suppression qui lui est associée';
$lang['news']['help_list3']='Vous pouvez modifier une actualité  en cliquant sur l\'icône de modification qui lui est associée';
$lang['news']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les actualités désirées';
$lang['news']['help_list5']='Pour ajouter une actualité, cliquez sur le lien \'ajouter une actualité\' dans la barre de titre';
$lang['news']['help_list6']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['news']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['news']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['news']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['news']['help_det1']='Vous pouvez supprimer cette actualité en cliquant sur l\'icône de suppression qui lui est associée';
$lang['news']['help_det2']='Vous pouvez modifier cette actualité en cliquant sur l\'icône de modification qui lui est associée';

$lang['news']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de l\'actualité en cours, cliquer sur \'Annuler\'';
?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/lang_news.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "actualités";

/*	nommage des modules
 *  	*/
$lang['news']['name']='actualité';
$lang['news']['confirm_add'] = "Ajout de la nouvelle actualité réalisé avec succès\n";
$lang['news']['confirm_mod'] = "Modification de l'actualité réalisée avec succès\n";
$lang['news']['confirm_sup'] ="Suppression de l'actualité réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Ajout d\'une '.$lang['news']['name'];
$lang['news']['mod']= 'Modification d\'une '.$lang['news']['name'];
$lang['news']['sup']= 'Suppression de l\''.$lang['news']['name'];
$lang['news']['det']= 'Détails de l\''.$lang['news']['name'];
$lang['news']['list']= 'Consultation des actualités';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Saisie des informations de la nouvelle '.$lang['news']['name'];
$lang['news']['mod_title']='Modification des informations de l\''.$lang['news']['name'];
$lang['news']['recap_commment']='aucun commentaire';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='Votre actualité doit impérativement être associée à une échelle';
$lang['news']['no_level']='Votre actualité doit impérativement être associée à un niveau';
$lang['news']['no_theme']='Votre actualité doit impérativement être associée à un thème';
$lang['news']['no_title']='Votre actualité doit impérativement contenir un titre';
$lang['news']['no_body']='Votre actualité doit impérativement avoir un contenu';
$lang['news']['no_header']='Votre actualité doit impérativement contenir un résumé';



/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='Titre de l\''.$lang['news']['name'];
$lang['news']['header']= 'entête';
$lang['news']['body']= 'contenu';
$lang['news']['theme']='thème de rattachement';
$lang['news']['level']='niveau de rattachement';
$lang['news']['scale']='échelle de rattachement';
$lang['news']['statut']='état de publication';
$lang['news']['author']='auteur';




/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' derniers ajouts effectués';
$lang['news']['qb_titlemod']=' dernières modifications effectuées';
$lang['news']['qb_titlesup']=' dernières suppressions effectuées';
$lang['news']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['news']['nb_total']='actualités sont stockées dans la base de données.';
$lang['news']['statut_filter']='Afficher par statut';
$lang['news']['all']='Afficher la liste complète';
$lang['news']['noresult']='Aucune actualité ne correspond à ce critère de sélection ';


/*	public
 *  	*/

$lang['news']['name2']='actualité(s)';
$lang['news']['next_news']='Voir l\'actualité suivante ';
$lang['news']['prev_news']='Voir l\'actualité précédente ';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='Pour ajouter une actualité, saisissez les informations requises dans le formulaire ci-dessus.';
$lang['news']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['news']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['news']['help_list1']='Pour afficher le détail d\'une actualité, cliquez sur le titre de celle-ci';
$lang['news']['help_list2']='Vous pouvez supprimer une actualité en cliquant sur l\'icône de suppression qui lui est associée';
$lang['news']['help_list3']='Vous pouvez modifier une actualité  en cliquant sur l\'icône de modification qui lui est associée';
$lang['news']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les actualités désirées';
$lang['news']['help_list5']='Pour ajouter une actualité, cliquez sur le lien \'ajouter une actualité\' dans la barre de titre';
$lang['news']['help_list6']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['news']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['news']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['news']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['news']['help_det1']='Vous pouvez supprimer cette actualité en cliquant sur l\'icône de suppression qui lui est associée';
$lang['news']['help_det2']='Vous pouvez modifier cette actualité en cliquant sur l\'icône de modification qui lui est associée';

$lang['news']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de l\'actualité en cours, cliquer sur \'Annuler\'';
?>
